@@ -25,12 +25,9 @@ class Cloud(object):
     def __setstate__(self, state):
         self.f = Husky.loads(state) 
 
-kvstore = KVStore(config.host, self.name)
+kvstore = KVStore(config.host, "CachedData")
 
 class CachedData(object):
-
-    name = "CachedData"
-
     def __init__(self, var):
         self.value = var
         self.put(self.value)
